# coding=utf-8
"""
作者：vissy@zhu
"""

import requests
import urllib3


class ConfigHttp():

    def __init__(self, scheme, api_url, www_url, web_url, port):
        self.scheme = scheme
        self.api_url = api_url
        self.www_url = www_url
        self.web_url = web_url
        self.port = port
        self.headers = {}
        # self.params = {}
        self.data = {}
        self.url = {}
        # self.files = {}
        self.state = 0

    def set_url(self, url):
        """
        set url
        :param: interface url
        :return:
        """
        self.__url = self.scheme + '://' + self.api_url + url

    def set_www_url(self, url):
        """
        set url
        :param: interface url
        :return:
        """
        self.__url = self.scheme + '://' + self.www_url + url

    def set_web_url(self, url):
        """
        set url
        :param: interface url
        :return:
        """
        self.__url = self.scheme + '://' + self.web_url + url

    def set_headers(self, header):
        """
        set headers
        :param header:
        :return:
        """
        self.headers = header

    def set_params(self, param):
        """
        set params
        :param param:
        :return:
        """
        self.params = param

    def set_data(self, data):
        """
        set data
        :param data:
        :return:
        """
        self.__data = data

    # defined http_data.py get method
    def get(self):
        """
        defined get method
        :return:
        """
        try:
            urllib3.disable_warnings()
            response = requests.get(self.url, headers=self.headers, params=self.params, verify=False)
            # response.raise_for_status()
            return response
        except TimeoutError:
            self.logger.error("Time out!")
            return None

    # defined http_data.py post method
    # include get params and post data
    # uninclude upload file
    def post(self):
        """
        defined post method
        :return:
        """
        try:
            urllib3.disable_warnings()
            response = requests.post(self.__url, headers=self.headers, json=self.__data, verify=False)
            # response.raise_for_status()
            return response
        except TimeoutError:
            return None



# coding=utf-8
"""
zx08443
"""

import pymysql


# 数据库连接
def connectdb(hostname, username, psw, port, dbname):
    connect = pymysql.connect(host=hostname, user=username, password=psw, port=port, db=dbname)
    c = connect.cursor()
    return connect, c  # 返回游标，执行sql语句，返回连接参数，是为了执行数据的更新sql，比如update和delete。



# coding=utf-8
"""
作者：vissy@zhu
"""
from setuptools import setup, find_packages
import ssl

ssl._create_default_https_context = ssl._create_unverified_context
setup(
    name="lyhapi",  # Replace with your own username
    version="0.0.10",
    author="vissyzhu",
    author_email="1209354095@qq.com",
    description="lyhcc information retriver",
    url="https://github.com/vissyzhu/lyhapi.git",
    license='MIT',
    packages=find_packages(),
    zip_safe=False
)
